# seven_cloudapp_frame

## 天志互联Python云应用框架库


### 1.0.11.11 更新内容
* 增加分享奖励任务和get_param_int方法

### 1.0.11.9 更新内容
* 活动表增加字段lc_order_id小部件orderId

### 1.0.11.8 更新内容
* 兼容淘宝小部件及其他平台 get_source_app_id方法优先取参数app_id 没有才是source_app_id

### 1.0.11.6 更新内容
* 控制台模型 erp_console_model 联调修复异常

### 1.0.11.2 更新内容
* 任务系统指定的任务模块添加了info_json参数，便于业务记录资产详细信息

### 1.0.11 更新内容
* 文件帮助类修改

### 1.0.10.42 更新内容
* 修改变更资产方法，去掉每日进销存,从控制台生成,加快处理速度  
* 新增统计处理方式，可以从redis处理，对性能要求高的走redis，对数据安全性，完整性要求高的走mysql 

### 1.0.10.39 更新内容
* 添加client接口 获取黑名单解封申请记录

### 1.0.10.38 更新内容
* 资产模块 asset_base_model.py 修改方法get_user_asset_list去掉排序参数

### 1.0.10 更新内容
* 排队系统 修改update_time

### 1.0.9 更新内容
* 微信昵称emoji处理

### 1.0.5 更新内容
* 排队系统帮助类加队列增加头像字段

### 1.0.3 更新内容
* prize_order_tb表新增字段freight_pay_order_no

### 1.0.2 更新内容
* 字符串序列化异常修复

### 1.0.0.222 更新内容
* 接口加解密异常修复

### 1.0.0.217 更新内容
* 排队系统异常修复

### 1.0.0.209 更新内容
* 免费领取任务奖励上报写死bug修复

### 1.0.0.205 更新内容
* 统计控制台bug修复

### 1.0.0.204 更新内容
* 添加加密帮助类及server添加ActPrizeListHandler事件重写

### 1.0.0.200 更新内容
* 修改pay.py中的请求参数转换成xml

### 1.0.0.197 更新内容
* 修改pay.py异步通知handler继承

### 1.0.0.196 更新内容
* 修改微信支付

### 1.0.0.193 更新内容
* 修改微信预订单Ip获取异常

### 1.0.0.191 更新内容
* 修改排队系统帮助类

### 1.0.0.190 更新内容
* 修改任务配置的整形字段强制转换

### 1.0.0.189 更新内容
* 云应用框架初始版